@@ -1,14 +1,16 @@
 from abc import abstractmethod, ABC
+from typing import Callable, List, Union
+
 from rx.core.typing import Observable
-from typing import Callable, List
 
 from gaia_sdk.graphql import RetrievalReq, ExperienceReq, KnowledgeReq, EdgeReq, \
-    IdentityReq, IntentReq, PromptReq, StatementReq, FulfilmentReq, CodeReq, BehaviourReq, IntrospectionReq, SkillIntrospectionReq, \
+    IdentityReq, IntentReq, PromptReq, StatementReq, FulfilmentReq, CodeReq, BehaviourReq, IntrospectionReq, \
     PerceptionReq, PreservationReq, CreatedIdentityImpulse, UpdatedIdentityImpulse, DeletedIdentityImpulse, \
     CreatedIntentImpulse, UpdatedIntentImpulse, DeletedIntentImpulse, RetrievalRes, \
     ExperienceRes, EdgeRes, StatementRes, PromptRes, IntentRes, IdentityRes, KnowledgeRes, FulfilmentRes, CodeRes, \
-    BehaviourRes, IntrospectionRes, SkillIntrospectionRes, PreservationRes, PerceptionRes, PerceivedImpulse, \
-    DeleteIdentityImpulse, UpdateIdentityImpulse, CreateIdentityImpulse, DeleteIntentImpulse, UpdateIntentImpulse, CreateIntentImpulse,  \
+    BehaviourRes, IntrospectionRes, PreservationRes, PerceptionRes, PerceivedImpulse, \
+    DeleteIdentityImpulse, UpdateIdentityImpulse, CreateIdentityImpulse, DeleteIntentImpulse, UpdateIntentImpulse, \
+    CreateIntentImpulse, \
     PerceiveActionImpulse, PerceiveDataImpulse, \
     CreatePromptImpulse, UpdatePromptImpulse, DeletePromptImpulse, CreatedPromptImpulse, UpdatedPromptImpulse, \
     DeletedPromptImpulse, CreateStatementImpulse, UpdateStatementImpulse, DeleteStatementImpulse, \
@@ -18,7 +20,11 @@ from gaia_sdk.graphql import RetrievalReq, ExperienceReq, KnowledgeReq, EdgeReq,
     CreatedBehaviourImpulse, UpdatedBehaviourImpulse, DeletedBehaviourImpulse, CreateCodeImpulse, UpdateCodeImpulse, \
     DeleteCodeImpulse, CreatedCodeImpulse, UpdatedCodeImpulse, DeletedCodeImpulse, CreateEdgeImpulse, \
     DeleteEdgeImpulse, CreatedEdgeImpulse, DeletedEdgeImpulse, BehaviourExecutionRes, BehaviourExecutionReq, \
-    BehaviourExecutionDetailReq, BehaviourExecutionDetailRes
+    BehaviourExecutionDetailReq, BehaviourExecutionDetailRes, \
+    CreatedSkillBuildJobImpulseRes, CreatedSkillBuildJobImpulseReq, \
+    CancelSkillBuildJobImpulse, CreateSkillBuildJobImpulse, CanceledSkillBuildJobImpulseRes, \
+    CanceledSkillBuildJobImpulseReq, \
+    PracticeReq, PracticeRes, SkillBuildJobRes, SkillBuildJobReq
 
 Uuid = str
 
@@ -114,10 +120,6 @@ class ISensorFunction(ABC):
     def introspect(self, config: Callable[[IntrospectionReq], None]) -> Observable[IntrospectionRes]:
         pass
 
-    @abstractmethod
-    def introspect_skills(self, config: Callable[[SkillIntrospectionReq], None]) -> Observable[SkillIntrospectionRes]:
-        pass
-
     @abstractmethod
     def preserve(self, config: Callable[[PreservationReq], None]) -> Observable[PreservationRes]:
         pass
@@ -225,3 +227,19 @@ class ISensorFunction(ABC):
     @abstractmethod
     def perceive_data(self, impulse: PerceiveDataImpulse) -> Observable[PerceivedImpulse]:
         pass
+
+    @abstractmethod
+    def practice(self, config: Callable[[PracticeReq], None]) -> Observable[PracticeRes]:
+        pass
+
+    @abstractmethod
+    def practice_build(self, impulse: CreateSkillBuildJobImpulse, config: Union[Callable[[CreatedSkillBuildJobImpulseReq], None], None] = None) -> Observable[CreatedSkillBuildJobImpulseRes]:
+        pass
+
+    @abstractmethod
+    def practice_cancel(self, impulse: CancelSkillBuildJobImpulse, config: Union[Callable[[CanceledSkillBuildJobImpulseReq], None], None] = None) -> Observable[CanceledSkillBuildJobImpulseRes]:
+        pass
+
+    @abstractmethod
+    def introspect_build_jobs(self, tenant_id: Uuid, config: Union[Callable[[SkillBuildJobReq], None], None] = None) -> Observable[SkillBuildJobRes]:
+        pass
\ No newline at end of file
