@@ -5,6 +5,7 @@ from gaia_sdk.api.VariableRegistry import VariableRegistry
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 
 class Tenant(list):
@@ -24,17 +25,5 @@ class Tenant(list):
     def qualifier(self):
         self.append(lambda x: "qualifier")
 
-    """
-    The list of implicit identities
-    """
-    def implicit_identities(self):
-        self.append(lambda x: "implicitIdentities")
-
-    """
-    The list of explicit identities
-    """
-    def explicit_identities(self):
-        self.append(lambda x: "explicitIdentities")
-
     def render(self, registry: VariableRegistry):
         return " ".join(map(lambda e: e(registry), self))
