@@ -3,6 +3,10 @@ from gaia_sdk.graphql.request.type.Fulfilment import Fulfilment
 
 from typing import Callable, List
 from gaia_sdk.api.VariableRegistry import VariableRegistry
+from gaia_sdk.graphql.request.enumeration.Order import Order
+from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 
 class UpdatedFulfilmentImpulse(list):
