@@ -43,35 +43,5 @@ class User(list):
     def last_name(self):
         self.append(lambda x: "lastName")
 
-    """
-    Is the User using 2FA
-    """
-    def using2_f_a(self):
-        self.append(lambda x: "using2FA")
-
-    """
-    The tenants of the user
-    """
-    def tenants(self):
-        self.append(lambda x: "tenants")
-
-    """
-    The roles of the user
-    """
-    def roles(self):
-        self.append(lambda x: "roles")
-
-    """
-    The groups of the user
-    """
-    def groups(self):
-        self.append(lambda x: "groups")
-
-    """
-    The permissions of the user
-    """
-    def permissions(self):
-        self.append(lambda x: "permissions")
-
     def render(self, registry: VariableRegistry):
         return " ".join(map(lambda e: e(registry), self))
