@@ -9,8 +9,6 @@ Struct = dict
 Float = float
 Int = int
 Boolean = bool
-from gaia_sdk.graphql.request.enumeration.RuntimeState import RuntimeState
-from gaia_sdk.graphql.request.enumeration.SkillState import SkillState
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
@@ -43,8 +41,8 @@ class BehaviourExecutionDetail:
     def qualifier(self) -> String:
         return String(self.dictionary.get("qualifier"))
     @property
-    def behaviour(self) -> String:
-        return String(self.dictionary.get("behaviour"))
+    def behaviours(self) -> Struct:
+        return Struct(self.dictionary.get("behaviours"))
     @property
     def behaviour_id(self) -> Uuid:
         return Uuid(self.dictionary.get("behaviourId"))
