@@ -8,11 +8,10 @@ Struct = dict
 Float = float
 Int = int
 Boolean = bool
-from gaia_sdk.graphql.request.enumeration.RuntimeState import RuntimeState
-from gaia_sdk.graphql.request.enumeration.SkillState import SkillState
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 class User:
     """
@@ -44,32 +43,20 @@ class User:
     def username(self) -> String:
         return String(self.dictionary.get("username"))
     """
-    Is the User using 2FA
+    The email of the user
     """
     @property
-    def using2_f_a(self) -> Boolean:
-        return Boolean(self.dictionary.get("using2FA"))
+    def email(self) -> String:
+        return String(self.dictionary.get("email"))
     """
-    The tenants of the user
+    The first name of the user
     """
     @property
-    def tenants(self) -> List[String]:
-        return list(map(lambda x: String(x), self.dictionary.get("tenants")))
+    def first_name(self) -> String:
+        return String(self.dictionary.get("firstName"))
     """
-    The roles of the user
+    The last name of the user
     """
     @property
-    def roles(self) -> List[String]:
-        return list(map(lambda x: String(x), self.dictionary.get("roles")))
-    """
-    The groups of the user
-    """
-    @property
-    def groups(self) -> List[String]:
-        return list(map(lambda x: String(x), self.dictionary.get("groups")))
-    """
-    The permissions of the user
-    """
-    @property
-    def permissions(self) -> List[String]:
-        return list(map(lambda x: String(x), self.dictionary.get("permissions")))
+    def last_name(self) -> String:
+        return String(self.dictionary.get("lastName"))
